/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "atspi-selection.h"

#include <string.h>

/* ------------------------------------------------------------------------ */
/* Definitions for org.a11y.atspi.Selection */

const GDBusArgInfo atspi_selection_interface__get_selected_child_method_in_args__selectedChildIndex_arg =
{
  -1,  /* ref count */
  (gchar *) "selectedChildIndex",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__get_selected_child_method_in_args[] =
{
  &atspi_selection_interface__get_selected_child_method_in_args__selectedChildIndex_arg,
  NULL,
};

const GDBusArgInfo atspi_selection_interface__get_selected_child_method_out_args__unnamed_arg1_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg1",
  (gchar *) "(so)",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__get_selected_child_method_out_args[] =
{
  &atspi_selection_interface__get_selected_child_method_out_args__unnamed_arg1_arg,
  NULL,
};

const GDBusAnnotationInfo atspi_selection_interface__get_selected_child_method_annotations__org_qtproject__qt_dbus__qt_type_name__out0_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.qtproject.QtDBus.QtTypeName.Out0",
  (gchar *) "QSpiObjectReference",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const atspi_selection_interface__get_selected_child_method_annotations[] =
{
  &atspi_selection_interface__get_selected_child_method_annotations__org_qtproject__qt_dbus__qt_type_name__out0_annotation,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__get_selected_child_method =
{
  -1,  /* ref count */
  (gchar *) "GetSelectedChild",
  (GDBusArgInfo **) atspi_selection_interface__get_selected_child_method_in_args,
  (GDBusArgInfo **) atspi_selection_interface__get_selected_child_method_out_args,
  (GDBusAnnotationInfo **) atspi_selection_interface__get_selected_child_method_annotations,
};

const GDBusArgInfo atspi_selection_interface__select_child_method_in_args__childIndex_arg =
{
  -1,  /* ref count */
  (gchar *) "childIndex",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__select_child_method_in_args[] =
{
  &atspi_selection_interface__select_child_method_in_args__childIndex_arg,
  NULL,
};

const GDBusArgInfo atspi_selection_interface__select_child_method_out_args__unnamed_arg1_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg1",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__select_child_method_out_args[] =
{
  &atspi_selection_interface__select_child_method_out_args__unnamed_arg1_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__select_child_method =
{
  -1,  /* ref count */
  (gchar *) "SelectChild",
  (GDBusArgInfo **) atspi_selection_interface__select_child_method_in_args,
  (GDBusArgInfo **) atspi_selection_interface__select_child_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo atspi_selection_interface__deselect_selected_child_method_in_args__selectedChildIndex_arg =
{
  -1,  /* ref count */
  (gchar *) "selectedChildIndex",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__deselect_selected_child_method_in_args[] =
{
  &atspi_selection_interface__deselect_selected_child_method_in_args__selectedChildIndex_arg,
  NULL,
};

const GDBusArgInfo atspi_selection_interface__deselect_selected_child_method_out_args__unnamed_arg1_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg1",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__deselect_selected_child_method_out_args[] =
{
  &atspi_selection_interface__deselect_selected_child_method_out_args__unnamed_arg1_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__deselect_selected_child_method =
{
  -1,  /* ref count */
  (gchar *) "DeselectSelectedChild",
  (GDBusArgInfo **) atspi_selection_interface__deselect_selected_child_method_in_args,
  (GDBusArgInfo **) atspi_selection_interface__deselect_selected_child_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo atspi_selection_interface__is_child_selected_method_in_args__childIndex_arg =
{
  -1,  /* ref count */
  (gchar *) "childIndex",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__is_child_selected_method_in_args[] =
{
  &atspi_selection_interface__is_child_selected_method_in_args__childIndex_arg,
  NULL,
};

const GDBusArgInfo atspi_selection_interface__is_child_selected_method_out_args__unnamed_arg1_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg1",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__is_child_selected_method_out_args[] =
{
  &atspi_selection_interface__is_child_selected_method_out_args__unnamed_arg1_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__is_child_selected_method =
{
  -1,  /* ref count */
  (gchar *) "IsChildSelected",
  (GDBusArgInfo **) atspi_selection_interface__is_child_selected_method_in_args,
  (GDBusArgInfo **) atspi_selection_interface__is_child_selected_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo atspi_selection_interface__select_all_method_out_args__unnamed_arg0_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg0",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__select_all_method_out_args[] =
{
  &atspi_selection_interface__select_all_method_out_args__unnamed_arg0_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__select_all_method =
{
  -1,  /* ref count */
  (gchar *) "SelectAll",
  NULL,  /* no in args */
  (GDBusArgInfo **) atspi_selection_interface__select_all_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo atspi_selection_interface__clear_selection_method_out_args__unnamed_arg0_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg0",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__clear_selection_method_out_args[] =
{
  &atspi_selection_interface__clear_selection_method_out_args__unnamed_arg0_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__clear_selection_method =
{
  -1,  /* ref count */
  (gchar *) "ClearSelection",
  NULL,  /* no in args */
  (GDBusArgInfo **) atspi_selection_interface__clear_selection_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo atspi_selection_interface__deselect_child_method_in_args__childIndex_arg =
{
  -1,  /* ref count */
  (gchar *) "childIndex",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__deselect_child_method_in_args[] =
{
  &atspi_selection_interface__deselect_child_method_in_args__childIndex_arg,
  NULL,
};

const GDBusArgInfo atspi_selection_interface__deselect_child_method_out_args__unnamed_arg1_arg =
{
  -1,  /* ref count */
  (gchar *) "unnamed_arg1",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const atspi_selection_interface__deselect_child_method_out_args[] =
{
  &atspi_selection_interface__deselect_child_method_out_args__unnamed_arg1_arg,
  NULL,
};

const GDBusMethodInfo atspi_selection_interface__deselect_child_method =
{
  -1,  /* ref count */
  (gchar *) "DeselectChild",
  (GDBusArgInfo **) atspi_selection_interface__deselect_child_method_in_args,
  (GDBusArgInfo **) atspi_selection_interface__deselect_child_method_out_args,
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const atspi_selection_interface_methods[] =
{
  &atspi_selection_interface__get_selected_child_method,
  &atspi_selection_interface__select_child_method,
  &atspi_selection_interface__deselect_selected_child_method,
  &atspi_selection_interface__is_child_selected_method,
  &atspi_selection_interface__select_all_method,
  &atspi_selection_interface__clear_selection_method,
  &atspi_selection_interface__deselect_child_method,
  NULL,
};

const GDBusPropertyInfo atspi_selection_interface__nselected_children_property =
{
  -1,  /* ref count */
  (gchar *) "NSelectedChildren",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const atspi_selection_interface_properties[] =
{
  &atspi_selection_interface__nselected_children_property,
  NULL,
};

const GDBusInterfaceInfo atspi_selection_interface =
{
  -1,  /* ref count */
  (gchar *) "org.a11y.atspi.Selection",
  (GDBusMethodInfo **) atspi_selection_interface_methods,
  NULL,  /* no signals */
  (GDBusPropertyInfo **) atspi_selection_interface_properties,
  NULL,  /* no annotations */
};

